@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.2.2'
+__version__   = '2.2.3'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2022-March-5'
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.2.html'
-__copyright__ = "(C) 2022 Avinash Kak. Python Software Foundation."
+__date__      = '2023-March-18'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.3.html'
+__copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
@@ -399,8 +399,7 @@ class DataPrediction(object):
             for i in range(sequence_length, num_records_in_file):
                 sequences_from_file[i - sequence_length] = dataframes[file][i-sequence_length : i]         
                 predictions_from_file[i - sequence_length] = dataframes[file][i,0]                  
-            ## We save 10% of the sequences for extracted from each data file for the final evaluation of the 
-            ## prediction model:
+            ## We save 10% of the sequences extracted from each data file for the final evaluation of the prediction model:
             test_portion = int(0.1*len(sequences_from_file))      
             if len(self.training_sequences) == 0:
                 self.training_sequences = sequences_from_file[:-test_portion]                                             
@@ -486,8 +485,9 @@ class DataPrediction(object):
     def run_code_for_evaluation_on_unseen_data(self, model):
         """
         We now evaluate the quality of the pmGRU based prediction model leanred from the training data.  The 
-        evaluation is carried out on the UNSEEN test data.  Recall, when the normalized load data in each file 
-        was digested by the method "construct_sequences_from_data()", 
+        evaluation is carried out on the UNSEEN test data.  Recall that when the normalized load data in each
+        file was digested by the method "construct_sequences_from_data()", we saved 10% of the sequences 
+        extracted from each data file for the final evaluation of the prediction model.
         """
         hidden_size = self.hidden_size
         device = self.dls.device
