@@ -17,7 +17,7 @@ import numpy
 import torch
 import os, sys
 
-
+"""
 seed = 0           
 random.seed(seed)
 torch.manual_seed(seed)
@@ -26,6 +26,7 @@ numpy.random.seed(seed)
 torch.backends.cudnn.deterministic=True
 torch.backends.cudnn.benchmarks=False
 os.environ['PYTHONHASHSEED'] = str(seed)
+"""
 
 
 ##  watch -d -n 0.5 nvidia-smi
@@ -33,8 +34,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 
-dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
-#dataroot = "./data/TextDatasets/sentiment_dataset/"
+#dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
+dataroot = "./data/TextDatasets/sentiment_dataset/"
 
 dataset_archive_train = "sentiment_dataset_train_40.tar.gz"
 #dataset_archive_train = "sentiment_dataset_train_200.tar.gz"
