@@ -46,11 +46,10 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 from Transformers import *
 
-#dataroot = "/home/kak/TextDatasets/en_es_corpus_xformer/"
+dataroot = "/home/kak/TextDatasets/en_es_corpus_xformer/"
 #dataroot = "/mnt/cloudNAS3/Avi/TextDatasets/en_es_corpus_xformer/"
-dataroot = "./data/"
+#dataroot = "./data/"
 
-#data_archive =  "en_es_xformer_8_10000.tar.gz"
 data_archive =  "en_es_xformer_8_90000.tar.gz"
 
 max_seq_length = 10
